@@ -12,19 +12,15 @@
 */
 
 #include "kcmmisc.h"
-#include "ui_kcmmiscwidget.h"
 #include "keyboardmiscsettings.h"
+#include "ui_kcmmiscwidget.h"
 
 #include <QButtonGroup>
 #include <QCheckBox>
 #include <QDoubleSpinBox>
 #include <QSpinBox>
 #include <QWhatsThis>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <QtGui/private/qtx11extras_p.h>
-#endif
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -74,7 +70,7 @@ KCMiscKeyboardWidget::KCMiscKeyboardWidget(QWidget *parent, KeyboardMiscSettings
     _numlockButtonGroup->addButton(ui.radioButton2, 1);
     _numlockButtonGroup->addButton(ui.radioButton3, 2);
 
-    connect(_numlockButtonGroup, SIGNAL(buttonClicked(int)), this, SLOT(changed()));
+    connect(_numlockButtonGroup, &QButtonGroup::idClicked, this, qOverload<>(&KCMiscKeyboardWidget::changed));
 
     _keyboardRepeatButtonGroup = new QButtonGroup(ui.repeatFormLayout);
     if (hasAccentSupport()) {
@@ -85,13 +81,11 @@ KCMiscKeyboardWidget::KCMiscKeyboardWidget(QWidget *parent, KeyboardMiscSettings
     _keyboardRepeatButtonGroup->addButton(ui.repeatRadioButton, 1);
     _keyboardRepeatButtonGroup->addButton(ui.nothingRadioButton, 2);
 
-    connect(_keyboardRepeatButtonGroup, SIGNAL(buttonClicked(int)), this, SLOT(changed()));
-    connect(_keyboardRepeatButtonGroup, SIGNAL(buttonClicked(int)), this, SLOT(keyboardRepeatStateChanged(int)));
+    connect(_keyboardRepeatButtonGroup, &QButtonGroup::idClicked, this, qOverload<>(&KCMiscKeyboardWidget::changed));
+    connect(_keyboardRepeatButtonGroup, &QButtonGroup::idClicked, this, &KCMiscKeyboardWidget::keyboardRepeatStateChanged);
 
-    connect(_numlockButtonGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked),
-            this, &KCMiscKeyboardWidget::updateUiDefaultIndicator);
-    connect(_keyboardRepeatButtonGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked),
-            this, &KCMiscKeyboardWidget::updateUiDefaultIndicator);
+    connect(_numlockButtonGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &KCMiscKeyboardWidget::updateUiDefaultIndicator);
+    connect(_keyboardRepeatButtonGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &KCMiscKeyboardWidget::updateUiDefaultIndicator);
 }
 
 KCMiscKeyboardWidget::~KCMiscKeyboardWidget()
@@ -167,13 +161,13 @@ QString KCMiscKeyboardWidget::quickHelp() const
 bool KCMiscKeyboardWidget::isSaveNeeded() const
 {
     return m_settings->keyboardRepeat() != keybehaviourNames[KeyBehaviour(_keyboardRepeatButtonGroup->checkedId())]
-            || m_settings->numLock() != TriStateHelper::getInt(TriStateHelper::getTriState(_numlockButtonGroup));
+        || m_settings->numLock() != TriStateHelper::getInt(TriStateHelper::getTriState(_numlockButtonGroup));
 }
 
 bool KCMiscKeyboardWidget::isDefault() const
 {
     return defaultValueKeyboardRepeat() == KeyBehaviour(_keyboardRepeatButtonGroup->checkedId())
-            && m_settings->defaultNumLockValue() == TriStateHelper::getInt(TriStateHelper::getTriState(_numlockButtonGroup));
+        && m_settings->defaultNumLockValue() == TriStateHelper::getInt(TriStateHelper::getTriState(_numlockButtonGroup));
 }
 
 void KCMiscKeyboardWidget::setDefaultIndicator(bool visible)
@@ -257,7 +251,7 @@ KeyBehaviour KCMiscKeyboardWidget::defaultValueKeyboardRepeat() const
     }
 
     const auto keys = keybehaviourNames.keys();
-    auto defaultRepeat = std::find_if(keys.constBegin(), keys.constEnd(), [=](const KeyBehaviour &key) {
+    auto defaultRepeat = std::find_if(keys.constBegin(), keys.constEnd(), [=, this](const KeyBehaviour &key) {
         return keybehaviourNames[key] == m_settings->defaultKeyboardRepeatValue();
     });
 
