@@ -5,28 +5,29 @@
 */
 
 #include "configcontainer.h"
-#include "configplugin.h"
 
+#include "configplugin.h"
 #include "inputbackend.h"
 
-#include <KWindowSystem/kwindowsystem.h>
+#include <KWindowSystem>
+
+#include <memory> // std::unique_ptr
 
 extern "C" {
 Q_DECL_EXPORT void kcminit()
 {
-    InputBackend *backend = InputBackend::implementation();
+    std::unique_ptr<InputBackend> backend(InputBackend::implementation());
     backend->kcmInit();
-    delete backend;
 }
 }
 
-ConfigContainer::ConfigContainer(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
+ConfigContainer::ConfigContainer(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
 {
     m_plugin = ConfigPlugin::implementation(this);
 }
 
-QSize ConfigContainer::minimumSizeHint() const
+/*QSize ConfigContainer::minimumSizeHint() const
 {
     return m_plugin->minimumSizeHint();
 }
@@ -39,6 +40,7 @@ void ConfigContainer::resizeEvent(QResizeEvent *event)
     Q_UNUSED(event);
     m_plugin->resize(this->size());
 }
+*/
 
 void ConfigContainer::load()
 {
@@ -55,8 +57,10 @@ void ConfigContainer::defaults()
     m_plugin->defaults();
 }
 
-void ConfigContainer::hideEvent(QHideEvent *e)
+/*void ConfigContainer::hideEvent(QHideEvent *e)
 {
     m_plugin->hideEvent(e);
     KCModule::hideEvent(e);
 }
+
+*/
