@@ -32,18 +32,6 @@ LibinputConfig::LibinputConfig(ConfigContainer *parent, InputBackend *backend)
 {
     m_backend = backend;
 
-    KAboutData *data = new KAboutData(QStringLiteral("kcmmouse"),
-                                      i18n("Pointer device KCM"),
-                                      QStringLiteral("1.0"),
-                                      i18n("System Settings module for managing mice and trackballs."),
-                                      KAboutLicense::GPL_V2,
-                                      i18n("Copyright 2018 Roman Gilg"),
-                                      QString());
-
-    data->addAuthor(i18n("Roman Gilg"), i18n("Developer"), QStringLiteral("subdiff@gmail.com"));
-
-    m_parent->setAboutData(data);
-
     m_initError = !m_backend->errorString().isNull();
 
     m_view = new QQuickWidget(this);
@@ -53,11 +41,11 @@ LibinputConfig::LibinputConfig(ConfigContainer *parent, InputBackend *backend)
     m_errorMessage->setWordWrap(true);
     m_errorMessage->setVisible(false);
 
-    QVBoxLayout *layout = new QVBoxLayout(parent);
+    QVBoxLayout *layout = new QVBoxLayout(parent->widget());
 
     layout->addWidget(m_errorMessage);
     layout->addWidget(m_view);
-    parent->setLayout(layout);
+    parent->widget()->setLayout(layout);
 
     m_view->setResizeMode(QQuickWidget::SizeRootObjectToView);
     m_view->setClearColor(Qt::transparent);
@@ -66,9 +54,20 @@ LibinputConfig::LibinputConfig(ConfigContainer *parent, InputBackend *backend)
     m_view->rootContext()->setContextProperty("backend", m_backend);
     m_view->rootContext()->setContextProperty("deviceModel", getDeviceList(m_backend));
 
+    QObject::connect(m_view, &QQuickWidget::statusChanged, [&](QQuickWidget::Status status) {
+        if (status == QQuickWidget::Ready) {
+            connect(m_view->rootObject(), SIGNAL(changeSignal()), this, SLOT(onChange()));
+        }
+    });
+
     m_view->engine()->rootContext()->setContextObject(new KLocalizedContext(m_view->engine()));
 
-    if (m_backend->mode() == InputBackendMode::XLibinput) {
+#if BUILD_KCM_MOUSE_X11
+    bool deviceless = m_backend->mode() == InputBackendMode::XLibinput;
+#else
+    bool deviceless = false;
+#endif
+    if (deviceless) {
         m_view->setSource(QUrl(QStringLiteral("qrc:/libinput/main_deviceless.qml")));
     } else {
         m_view->setSource(QUrl(QStringLiteral("qrc:/libinput/main.qml")));
@@ -81,22 +80,14 @@ LibinputConfig::LibinputConfig(ConfigContainer *parent, InputBackend *backend)
     } else {
         connect(m_backend, SIGNAL(deviceAdded(bool)), this, SLOT(onDeviceAdded(bool)));
         connect(m_backend, SIGNAL(deviceRemoved(int)), this, SLOT(onDeviceRemoved(int)));
-        connect(m_view->rootObject(), SIGNAL(changeSignal()), this, SLOT(onChange()));
     }
 
+    // Just set it to a reasonable default size
+    // This only matters for kcmshell and most of the time we have the KCM in systemsettings open
+    m_view->resize(QSize(300, 300));
     m_view->show();
 }
 
-QSize LibinputConfig::sizeHint() const
-{
-    return QQmlProperty::read(m_view->rootObject(), QStringLiteral("sizeHint")).toSize();
-}
-
-QSize LibinputConfig::minimumSizeHint() const
-{
-    return QQmlProperty::read(m_view->rootObject(), QStringLiteral("minimumSizeHint")).toSize();
-}
-
 void LibinputConfig::load()
 {
     // in case of critical init error in backend, don't try
@@ -130,7 +121,7 @@ void LibinputConfig::save()
     // load newly written values
     load();
     // in case of error, config still in changed state
-    Q_EMIT m_parent->changed(m_backend->isChangedConfig());
+    m_parent->setNeedsSave(m_backend->isChangedConfig());
 }
 
 void LibinputConfig::defaults()
@@ -146,7 +137,7 @@ void LibinputConfig::defaults()
         m_errorMessage->animatedShow();
     }
     QMetaObject::invokeMethod(m_view->rootObject(), "syncValuesFromBackend");
-    Q_EMIT m_parent->changed(m_backend->isChangedConfig());
+    m_parent->setNeedsSave(m_backend->isChangedConfig());
 }
 
 void LibinputConfig::onChange()
@@ -155,7 +146,7 @@ void LibinputConfig::onChange()
         return;
     }
     hideErrorMessage();
-    Q_EMIT m_parent->changed(m_backend->isChangedConfig());
+    m_parent->setNeedsSave(m_backend->isChangedConfig());
 }
 
 void LibinputConfig::onDeviceAdded(bool success)
@@ -203,7 +194,7 @@ void LibinputConfig::onDeviceRemoved(int index)
     QMetaObject::invokeMethod(m_view->rootObject(), "resetModel", Q_ARG(QVariant, activeIndex));
     QMetaObject::invokeMethod(rootObj, "syncValuesFromBackend");
 
-    Q_EMIT m_parent->changed(m_backend->isChangedConfig());
+    m_parent->setNeedsSave(m_backend->isChangedConfig());
 }
 
 void LibinputConfig::hideErrorMessage()
