@@ -17,6 +17,8 @@
 #include <QScreen>
 #include <QStandardItemModel>
 
+using namespace Qt::StringLiterals;
+
 K_PLUGIN_CLASS_WITH_JSON(Touchscreen, "kcm_touchscreen.json")
 
 class OutputsModel : public QStandardItemModel
@@ -78,8 +80,9 @@ Touchscreen::Touchscreen(QObject *parent, const KPluginMetaData &metaData)
     : KQuickManagedConfigModule(parent, metaData)
     , m_touchscreensModel(new DevicesModel("touch", this))
 {
-    qmlRegisterType<OutputsModel>("org.kde.plasma.touchscreen.kcm", 1, 0, "OutputsModel");
-    qmlRegisterAnonymousType<InputDevice>("org.kde.plasma.touchscreen.kcm", 1);
+    const char *uri = "org.kde.plasma.touchscreen.kcm";
+    qmlRegisterType<OutputsModel>(uri, 1, 0, "OutputsModel");
+    qmlRegisterUncreatableType<InputDevice>(uri, 1, 0, "InputDevice", u"Should be fetched from kcm.touchscreensModel"_s);
 
     connect(m_touchscreensModel, &DevicesModel::needsSaveChanged, this, &Touchscreen::refreshNeedsSave);
 }
