@@ -29,24 +29,14 @@
 K_PLUGIN_FACTORY_WITH_JSON(DeviceAutomounterKCMFactory, "device_automounter_kcm.json", registerPlugin<DeviceAutomounterKCM>();
                            registerPlugin<DeviceAutomounterData>();)
 
-DeviceAutomounterKCM::DeviceAutomounterKCM(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args) // DeviceAutomounterKCMFactory::componentData(), parent)
-    , m_settings(new AutomounterSettings(this))
+DeviceAutomounterKCM::DeviceAutomounterKCM(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
+    , m_settings(new AutomounterSettings(widget()))
     , m_devices(new DeviceModel(m_settings, this))
 {
-    KAboutData *about = new KAboutData(QStringLiteral("kcm_device_automounter"),
-                                       i18n("Device Automounter"),
-                                       QStringLiteral("2.0"),
-                                       QString(),
-                                       KAboutLicense::GPL_V2,
-                                       i18n("(c) 2009 Trever Fischer, (c) 2015 Kai Uwe Broulik"));
-    about->addAuthor(i18n("Trever Fischer"), i18n("Original Author"));
-    about->addAuthor(i18n("Kai Uwe Broulik"), i18n("Plasma 5 Port"), QStringLiteral("kde@privat.broulik.de"));
+    setupUi(widget());
 
-    setAboutData(about);
-    setupUi(this);
-
-    addConfig(m_settings, this);
+    addConfig(m_settings, widget());
 
     deviceView->setModel(m_devices);
 
@@ -146,17 +136,17 @@ void DeviceAutomounterKCM::save()
 
     // Now tell kded to automatically load the module if loaded
     QDBusConnection dbus = QDBusConnection::sessionBus();
-    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded5"),
+    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded6"),
                                                       QStringLiteral("/kded"),
-                                                      QStringLiteral("org.kde.kded5"),
+                                                      QStringLiteral("org.kde.kded6"),
                                                       QStringLiteral("setModuleAutoloading"));
     msg.setArguments({QVariant(QStringLiteral("device_automounter")), QVariant(enabled)});
     dbus.call(msg, QDBus::NoBlock);
 
     // Load or unload right away
-    msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded5"),
+    msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded6"),
                                          QStringLiteral("/kded"),
-                                         QStringLiteral("org.kde.kded5"),
+                                         QStringLiteral("org.kde.kded6"),
                                          enabled ? QStringLiteral("loadModule") : QStringLiteral("unloadModule"));
     msg.setArguments({QVariant(QStringLiteral("device_automounter"))});
     dbus.call(msg, QDBus::NoBlock);
